/// <reference types="node" />
export declare type Endianness = 'le' | 'be';
declare class BNClass {
    constructor(number: number | string | number[] | Uint8Array | Buffer | BNClass, endian?: Endianness);
    constructor(number: number | string | number[] | Uint8Array | Buffer | BNClass, base?: number | 'hex', endian?: Endianness);
    /**
     * @description  convert to byte Array, and optionally zero pad to length, throwing if already exceeding
     */
    toArray(endian?: Endianness, length?: number): number[];
    /**
     * @description  convert to base-string and pad with zeroes
     */
    toString(base?: number | 'hex', length?: number): string;
    /**
     * @description compare numbers and return `-1 (a < b)`, `0 (a == b)`, or `1 (a > b)` depending on the comparison result
     */
    ucmp(b: BNClass): -1 | 0 | 1;
    /**
     * @description convert to Javascript Number (limited to 53 bits)
     */
    toNumber(): number;
    /**
     * @description raise `a` to the power of `b`
     */
    pow(b: BNClass): BNClass;
    /**
     * @description multiply
     */
    mul(b: BNClass): BNClass;
    /**
     * @description addition
     */
    add(b: BNClass): BNClass;
}
export declare const BNConstructor: typeof BNClass;
export declare type BN = BNClass;
export {};
