"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isSubtleCryptoAvailable() {
    return typeof crypto !== 'undefined' && typeof crypto.subtle !== 'undefined';
}
exports.isSubtleCryptoAvailable = isSubtleCryptoAvailable;
exports.NO_CRYPTO_LIB = 'Crypto lib not found. Either the WebCrypto "crypto.subtle" or Node.js "crypto" module must be available.';
// Make async for future version which may lazy load.
// eslint-disable-next-line @typescript-eslint/require-await
async function getCryptoLib() {
    if (isSubtleCryptoAvailable()) {
        return {
            lib: crypto.subtle,
            name: 'subtleCrypto'
        };
    }
    else {
        try {
            // eslint-disable-next-line max-len
            // eslint-disable-next-line import/no-nodejs-modules,no-restricted-modules,global-require,@typescript-eslint/no-var-requires
            const nodeCrypto = require('crypto');
            return {
                lib: nodeCrypto,
                name: 'nodeCrypto'
            };
        }
        catch (error) {
            throw new Error(exports.NO_CRYPTO_LIB);
        }
    }
}
exports.getCryptoLib = getCryptoLib;
//# sourceMappingURL=cryptoUtils.js.map