"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cryptoUtils_1 = require("./cryptoUtils");
class NodeCryptoHmacSha256 {
    constructor(createHmac) {
        this.createHmac = createHmac;
    }
    async digest(key, data) {
        const result = this.createHmac('sha256', key)
            .update(data)
            .digest();
        return Promise.resolve(result);
    }
}
class WebCryptoHmacSha256 {
    constructor(subtleCrypto) {
        this.subtleCrypto = subtleCrypto;
    }
    async digest(key, data) {
        const cryptoKey = await this.subtleCrypto.importKey('raw', key, { name: 'HMAC', hash: 'SHA-256' }, true, ['sign']);
        const sig = await this.subtleCrypto.sign('HMAC', cryptoKey, data);
        return Buffer.from(sig);
    }
}
async function createHmacSha256() {
    const cryptoLib = await cryptoUtils_1.getCryptoLib();
    if (cryptoLib.name === 'subtleCrypto') {
        return new WebCryptoHmacSha256(cryptoLib.lib);
    }
    else {
        return new NodeCryptoHmacSha256(cryptoLib.lib.createHmac);
    }
}
exports.createHmacSha256 = createHmacSha256;
//# sourceMappingURL=hmacSha256.js.map