"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cryptoUtils_1 = require("./cryptoUtils");
class NodeCryptoSha2Hash {
    constructor(createHash) {
        this.createHash = createHash;
    }
    async digest(data, algorithm = 'sha256') {
        const result = this.createHash(algorithm)
            .update(data)
            .digest();
        return Promise.resolve(result);
    }
}
class WebCryptoSha2Hash {
    constructor(subtleCrypto) {
        this.subtleCrypto = subtleCrypto;
    }
    async digest(data, algorithm = 'sha256') {
        let algo;
        if (algorithm === 'sha256') {
            algo = 'SHA-256';
        }
        else if (algorithm === 'sha512') {
            algo = 'SHA-512';
        }
        else {
            throw new Error(`Unsupported hash algorithm ${algorithm}`);
        }
        const hash = await this.subtleCrypto.digest(algo, data);
        return Buffer.from(hash);
    }
}
async function createSha2Hash() {
    const cryptoLib = await cryptoUtils_1.getCryptoLib();
    if (cryptoLib.name === 'subtleCrypto') {
        return new WebCryptoSha2Hash(cryptoLib.lib);
    }
    else {
        return new NodeCryptoSha2Hash(cryptoLib.lib.createHash);
    }
}
exports.createSha2Hash = createSha2Hash;
//# sourceMappingURL=sha2Hash.js.map