"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bitcoinjs_lib_1 = require("bitcoinjs-lib");
const cryptoRandom_1 = require("./encryption/cryptoRandom");
const sha2Hash_1 = require("./encryption/sha2Hash");
const hashRipemd160_1 = require("./encryption/hashRipemd160");
/**
 *
 * @param numberOfBytes
 *
 * @ignore
 */
function getEntropy(arg) {
    if (!arg) {
        arg = 32;
    }
    return cryptoRandom_1.randomBytes(arg);
}
exports.getEntropy = getEntropy;
/**
* @ignore
*/
function makeECPrivateKey() {
    const keyPair = bitcoinjs_lib_1.ECPair.makeRandom({ rng: getEntropy });
    return keyPair.privateKey.toString('hex');
}
exports.makeECPrivateKey = makeECPrivateKey;
/**
* @ignore
*/
async function publicKeyToAddress(publicKey) {
    const publicKeyBuffer = Buffer.isBuffer(publicKey) ? publicKey : Buffer.from(publicKey, 'hex');
    const sha2Hash = await sha2Hash_1.createSha2Hash();
    const publicKeyHash160 = await hashRipemd160_1.createHashRipemd160().digest(await sha2Hash.digest(publicKeyBuffer));
    const address = bitcoinjs_lib_1.address.toBase58Check(publicKeyHash160, bitcoinjs_lib_1.networks.bitcoin.pubKeyHash);
    return address;
}
exports.publicKeyToAddress = publicKeyToAddress;
/**
* @ignore
*/
function getPublicKeyFromPrivate(privateKey) {
    const privateKeyBuffer = Buffer.isBuffer(privateKey) ? privateKey : Buffer.from(privateKey, 'hex');
    const keyPair = bitcoinjs_lib_1.ECPair.fromPrivateKey(privateKeyBuffer);
    return keyPair.publicKey.toString('hex');
}
exports.getPublicKeyFromPrivate = getPublicKeyFromPrivate;
//# sourceMappingURL=keys.js.map