"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const serviceUtils_1 = require("./serviceUtils");
const fetchUtil_1 = require("../../fetchUtil");
/**
 * @ignore
 */
class Service {
    async validateProof(proof, ownerAddress, cheerio, name = null) {
        try {
            const proofUrl = this.getProofUrl(proof);
            const res = await fetchUtil_1.fetchPrivate(proofUrl);
            if (res.status !== 200) {
                throw new Error(`Proof url ${proofUrl} returned unexpected http status ${res.status}.
            Unable to validate proof.`);
            }
            const text = await res.text();
            // Validate identity in provided proof body/tags if required
            if (this.shouldValidateIdentityInBody()
                && proof.identifier !== this.getProofIdentity(text, cheerio)) {
                return proof;
            }
            const proofText = this.getProofStatement(text, cheerio);
            proof.valid = serviceUtils_1.containsValidProofStatement(proofText, name)
                || serviceUtils_1.containsValidAddressProofStatement(proofText, ownerAddress);
            return proof;
        }
        catch (error) {
            console.error(error);
            proof.valid = false;
            return proof;
        }
    }
    shouldValidateIdentityInBody() {
        return false;
    }
    prefixScheme(proofUrl) {
        if (!proofUrl.startsWith('https://') && !proofUrl.startsWith('http://')) {
            return `https://${proofUrl}`;
        }
        else if (proofUrl.startsWith('http://')) {
            return proofUrl.replace('http://', 'https://');
        }
        else {
            return proofUrl;
        }
    }
}
exports.Service = Service;
//# sourceMappingURL=service.js.map